package com.ynet.life.sujrb.base;

import com.ynet.gene.component.factory.GENEFlowComponentFactory;
import com.ynet.gene.core.GENEException;
import com.ynet.life.base.LifeBusinessInfo;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.LifeInitializer;
import com.ynet.life.base.LifePlatManager;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.TEntity;
import com.ynet.life.base.Trace;
import com.ynet.life.base.logon.LifeLogonManager;
import com.ynet.life.controller.LifeAccessCenter;
import com.ynet.life.formValidation.FormValidationProvider;
import com.ynet.life.loaf.DataMappingProvider;
import com.ynet.life.log.LifeActionLoggerFactory;
import com.ynet.life.message.MessageFormatter;
import com.ynet.life.sujrb.cacheConfig.CacheContentConfigXMLReader;
import com.ynet.life.sujrb.log.PBActionLogger;
import java.sql.Connection;
import java.util.ArrayList;
import java.util.Hashtable;
import java.util.List;
import java.util.Map;

/* loaded from: com_ynet_life_sujrb_base.jar:com/ynet/life/sujrb/base/JRBInitializer.class */
public class JRBInitializer extends LifeInitializer {
    private static final String LOAF_FILE_LOCATION = "/WEB-INF/LOAFConfig.xml";
    private static final String VALIDATION_FILE_LOCATION = "/WEB-INF/FormValidation.xml";
    private static final String INTERFACE_CONFIG_FILE_LOCATION = "/WEB-INF/InterfaceConfigs.xml";
    private static final String SENDMSG_FILE_LOCATION = "WEB-INF/messageConfig.xml";
    private static final String SQL_SELECT_BUSSINESSINFO = "SELECT BDF_BSNCODE, BDF_NAME FROM PB_BSNDEF";
    private static final String SQL_SELECT_BSN_LINK = "SELECT BLK_BSNCODE,BLK_LINKBSN FROM PB_BSNLINK";
    private static final String SQL_SELECT_PRIVATE_QUESTION = "SELECT PQT_NO,PQT_QUESTION FROM PB_PRIVATE_QUESTION";
    private static final String SQL_WHILTE_LIST = "SELECT WHI_LOGONID FROM PB_WHITE_LIST";
    private static final String MVC_CONFIG_FILE_LOCATION = "/mvcs";
    private static final String CACHE_CONFIG_LOCATION = "/WEB-INF/CacheContentConfig.xml";

    public void initialize(GENEFlowComponentFactory factory) throws Exception {
        Connection connection = null;
        try {
            try {
                super.initialize(factory);
                String rootPath = LifeStandard.getRootPath();
                String dataSourcePath = String.valueOf(rootPath) + TEntity.databasePath;
                initDataSource(dataSourcePath);
                String gateWaypath = String.valueOf(rootPath) + TEntity.gateWayPath;
                initGateWay(gateWaypath);
                connection = LifeDBAccess.getConnection();
                LifeLogonManager.initialize(new PBLogonEntryConfig());
                LifeAccessCenter.initialize(new PBAccessControl());
                LifeActionLoggerFactory.initialize(new PBActionLogger());
                PBStandard.initialize(initBusinessInfo(connection));
                PBMenuTree.initialize(rootPath);
                DataMappingProvider.initTableConfig(String.valueOf(rootPath) + LOAF_FILE_LOCATION);
                PBStandard.initPrivateQuestion(initPrivateQuestion(connection));
                FormValidationProvider.initTableConfig(String.valueOf(rootPath) + VALIDATION_FILE_LOCATION);
                PBStandard.initializeCacheContent(CacheContentConfigXMLReader.readCacheContent(String.valueOf(rootPath) + CACHE_CONFIG_LOCATION));
                PBStandard.initWhiteList(initWhiteList(connection));
                MessageFormatter.initMessageConfig(String.valueOf(rootPath) + SENDMSG_FILE_LOCATION);
                LifeDBAccess.releaseConnection(connection);
            } catch (Exception ex) {
                Trace.logError("LifeAction", "初始化信息失败", ex);
                throw ex;
            }
        } catch (Throwable th) {
            LifeDBAccess.releaseConnection(connection);
            throw th;
        }
    }

    private void initDataSource(String dataSourcePath) {
        LifePlatManager.initBankDBSource();
    }

    private void initGateWay(String gateWayPath) {
        LifePlatManager.initBankGateway();
    }

    private static Map initBusinessInfo(Connection connection) throws GENEException {
        return new Hashtable();
    }

    private static void initBusinessLink(Connection connection) throws GENEException {
    }

    private static void addBusinessInfo(Map businessInfoTable, LifeBusinessInfo businessInfo) {
    }

    private static Map initPrivateQuestion(Connection connection) throws GENEException {
        return new Hashtable();
    }

    private static List initWhiteList(Connection connection) throws GENEException {
        return new ArrayList();
    }
}
